==> jc-1.4.0.tar.gz: gnu/java/locale/LocaleHelper.h <==
// public class gnu.java.locale.LocaleHelper

// class file dependencies
// @dep_class 1f02ccad622178ef gnu_java_locale_LocaleHelper
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_locale_LocaleHelper_H_
#define _JC_gnu_java_locale_LocaleHelper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Locale$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleHelper$sub_refs	_jc_gnu_java_locale_LocaleHelper$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleHelper$sub_nonrefs	_jc_gnu_java_locale_LocaleHelper$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleHelper$refs	_jc_gnu_java_locale_LocaleHelper$refs;
typedef struct _jc_gnu_java_locale_LocaleHelper$nonrefs	_jc_gnu_java_locale_LocaleHelper$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleHelper$object	_jc_gnu_java_locale_LocaleHelper$object;

typedef const struct _jc_gnu_java_locale_LocaleHelper$vmethods	_jc_gnu_java_locale_LocaleHelper$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleHelper$vtable	_jc_gnu_java_locale_LocaleHelper$vtable;
typedef const struct _jc_gnu_java_locale_LocaleHelper$vtype	_jc_gnu_java_locale_LocaleHelper$vtype;

// Constructors
extern void _jc_gnu_java_locale_LocaleHelper$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleHelper$object *);

// Static methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_locale_LocaleHelper$method$getLocalizedString$052223539f1400a0(_jc_env *, struct _jc_java_util_Locale$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jboolean, jboolean);

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleHelper$vmethods {
};

// Vtable
struct _jc_gnu_java_locale_LocaleHelper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_locale_LocaleHelper$vmethods	gnu_java_locale_LocaleHelper;
};

// Vtype
struct _jc_gnu_java_locale_LocaleHelper$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleHelper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleHelper$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleHelper$refs {
    _jc_gnu_java_locale_LocaleHelper$sub_refs	gnu_java_locale_LocaleHelper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleHelper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleHelper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_locale_LocaleHelper$sub_nonrefs	gnu_java_locale_LocaleHelper;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleHelper$object {
	_jc_gnu_java_locale_LocaleHelper$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleHelper$vtype	*vtype;
	_jc_gnu_java_locale_LocaleHelper$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleHelper$vtype _jc_gnu_java_locale_LocaleHelper$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleHelper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleHelper$class_object;

#endif	/* _JC_gnu_java_locale_LocaleHelper_H_ */

==> jc-1.4.5.tar.gz: gnu/java/locale/LocaleHelper.h <==
// public class gnu.java.locale.LocaleHelper

// class file dependencies
// @dep_class 4574698b3568b035 gnu_java_locale_LocaleHelper
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_locale_LocaleHelper_H_
#define _JC_gnu_java_locale_LocaleHelper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Locale$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleHelper$sub_refs	_jc_gnu_java_locale_LocaleHelper$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleHelper$sub_nonrefs	_jc_gnu_java_locale_LocaleHelper$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleHelper$refs	_jc_gnu_java_locale_LocaleHelper$refs;
typedef struct _jc_gnu_java_locale_LocaleHelper$nonrefs	_jc_gnu_java_locale_LocaleHelper$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleHelper$object	_jc_gnu_java_locale_LocaleHelper$object;

typedef const struct _jc_gnu_java_locale_LocaleHelper$vmethods	_jc_gnu_java_locale_LocaleHelper$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleHelper$vtable	_jc_gnu_java_locale_LocaleHelper$vtable;
typedef const struct _jc_gnu_java_locale_LocaleHelper$vtype	_jc_gnu_java_locale_LocaleHelper$vtype;

// Constructors
extern void _jc_gnu_java_locale_LocaleHelper$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleHelper$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_locale_LocaleHelper$method$getLocalizedString$052223539f1400a0(_jc_env *, struct _jc_java_util_Locale$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jboolean, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleHelper$vmethods {
};

// Vtable
struct _jc_gnu_java_locale_LocaleHelper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_locale_LocaleHelper$vmethods	gnu_java_locale_LocaleHelper;
};

// Vtype
struct _jc_gnu_java_locale_LocaleHelper$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleHelper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleHelper$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleHelper$refs {
    _jc_gnu_java_locale_LocaleHelper$sub_refs	gnu_java_locale_LocaleHelper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleHelper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleHelper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_locale_LocaleHelper$sub_nonrefs	gnu_java_locale_LocaleHelper;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleHelper$object {
	_jc_gnu_java_locale_LocaleHelper$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleHelper$vtype	*vtype;
	_jc_gnu_java_locale_LocaleHelper$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleHelper$vtype _jc_gnu_java_locale_LocaleHelper$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleHelper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleHelper$class_object;

#endif	/* _JC_gnu_java_locale_LocaleHelper_H_ */
